==> qmmp-0.6.8.tar.bz2: qmmp-0.6.8/src/plugins/Input/wildmidi/translations/wildmidi_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="43"/>
        <source>WildMidi Plugin</source>
        <translation>תוספת WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="45"/>
        <source>Midi Files</source>
        <translation>קבצי Midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="100"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>אודות תוספת שמע WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="101"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>תוספת שמע WildMidi ‫Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="102"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>תוספת עושה ניצול בספריית WildMidi לניגון של קבצי midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="103"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov ‫&lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>הגדרות תוספת WildMidi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>תצורת מכשיר: </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Sample rate:</source>
        <translation>שיעור דגימה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="60"/>
        <source>Enhanced resampling</source>
        <translation>דגימה מחדש משופרת</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Reverberation</source>
        <translation>הדהוד</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>44100 Hz</source>
        <translation>44100 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>48000 Hz</source>
        <translation>48000 הרץ</translation>
    </message>
</context>
</TS>

==> qmmp-0.7.5.tar.bz2: qmmp-0.7.5/src/plugins/Input/wildmidi/translations/wildmidi_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="43"/>
        <source>WildMidi Plugin</source>
        <translation>תוספת WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="45"/>
        <source>Midi Files</source>
        <translation>קבצי Midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="100"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>אודות תוספת שמע WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="101"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>תוספת שמע WildMidi ‫Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="102"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>תוספת זו עושה שימוש בספריית WildMidi לניגון של קבצי midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="103"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov ‫&lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>הגדרות תוספת WildMidi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>תצורת מכשיר: </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>שיעור דגימה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>דגימה מחדש משופרת</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>הדהוד</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 הרץ</translation>
    </message>
</context>
</TS>
